﻿using System;
using System.Collections.Generic;
using System.Text;
using Sciter.Forms;
using Sciter;

namespace Demo2.Forms
{
    class FrmHtmlFormData : Form
    {
        public FrmHtmlFormData(Form parent, SciterElement button) : base(parent)
        {

            Button = button;
            Width = 700;
            Height = 400;
            WindowStyle = WindowStyles.FixedSize; //固定大小

            IconInTaskBar = true;
            //该子窗体因为不是模式窗体或对话窗体，能最小化，
            //所以将IconInTaskBar属性设为真，使其图标能在任务中显示，
            //目的是当其最小化后，能从任务栏中方便地找到它。

            //绑定与之对应的HTML页
            StartupPage = Encoding.UTF8.GetBytes(Properties.Resources.FrmHtmlFormData);
        }

        public SciterElement Button { get; }

        /// <summary>
        /// 对HTML表单域对应的数据结构
        /// </summary>
        class FormData
        {
            /// <summary>
            /// 姓名
            /// </summary>
            public string Name = "";
            /// <summary>
            /// 住址
            /// </summary>
            public string Home = "";
        }


        /// <summary>
        /// 按钮被点击事件
        /// </summary>
        /// <param name="source"></param>
        /// <returns></returns>
        protected override bool OnButtonClick(SciterElement source)
        {
            var id = source?.GetId();

            //如果是赋值按钮被点击
            if (id == "setdata")
            {
                //数据源
                var sdata = new FormData
                {
                    Name = "张三[" + DateTime.Now.Second + "]",
                    Home = "中华人民共和国 台湾省台北市"
                };

                // 转为字典
                var value = new Dictionary<string, SciterValue>
                {
                    ["Name"] = new SciterValue(sdata.Name),
                    ["Home"] = new SciterValue(sdata.Home)
                };

                // 将字典转为SciterValue
                var data = SciterValue.FromDictionary(value);

                // 根据ID获取HTML表单对象
                var form = RootElement.SelectFirstById("MyForm");

                // 给表单赋值
                form.Value = data;

                // 表示已响应
                return true;
            }


            return base.OnButtonClick(source);
        }


        /// <summary>
        /// 表单提交事件
        /// </summary>
        /// <param name="source">表单对象</param>
        /// <param name="target">提交按钮</param>
        /// <param name="data"></param>
        protected override void OnFormSubmit(SciterElement source, SciterElement target, SciterValue data)
        {
            // 求数据源（表单）ID
            var htmFormId = source.GetId();

            //如果不是我们指定的表单
            if (htmFormId != "MyForm")
            {
                base.OnFormSubmit(source, target, data);
                return;
            }

            //将表单数据转为C#对象
            var form = data.MapToClass<FormData>();

            //显示结果
            var s = string.Format("姓名：{0}\n\n住址：{1}", form.Name, form.Home);
            ShowMessageBox(s, "表单数据", MessageBox.MsgIcon.None);


            // 附注：也可以通过OnButtonClick事件获取表单数据，并非只能用提交按钮

        }


    }
}
