﻿using System.Text;
using Sciter.Forms;
using Sciter;
using System.Threading;
using System;

namespace Demo2.Forms
{


    /// <summary>
    /// 主窗体类
    /// </summary>
    class FrmMain : Form
    {

        /// <summary>
        /// 窗口HTML中用于显示时间的标签对象
        /// </summary>
        SciterElement _label_DateTime;

        /// <summary>
        /// 用于定时刷新HTML中时间标签内容的定时器
        /// </summary>
        Timer _dtTimer;


        /// <summary>
        /// 主窗体构造函数
        /// </summary>
        public FrmMain()
        {
            Title = "Sciter.Forms 演示二";        // 窗体标题
            Width = 800;                          // 窗体宽度
            Height = 450;                         // 窗体高度
            Icon = WinApplication.ExeIconFirst;   // 窗体图标


            // 窗体界面：绑定HTML
            //（本HTML已经添加到程序的资源中了，所以直接从资源中加载）
            StartupPage = Encoding.UTF8.GetBytes(Properties.Resources.FrmMain);
        }



        /// <summary>
        /// 窗体创建完成事件（但还没有显示，也没有加载HTML）
        /// </summary>
        protected override void OnCreated()
        {
            //创建一个定时器，用于定时更新HTML中显示时间的标签
            _dtTimer = new Timer(MyTimerEvent, null, 80, 999);
        }


        /// <summary>
        /// 窗体加载HTML完成事件
        /// </summary>
        /// <param name="el"></param>
        protected override void OnReady(SciterElement el)
        {
            if (el == null || el.Parent != null) return;

            // 获取用于显示时候的标签对象
            _label_DateTime = el.SelectFirstById("txt_datetime");
        }


        /// <summary>
        /// 窗体收到其它线程发送过来的消息
        /// </summary>
        /// <param name="state">附带过来的对象</param>
        protected override void OnNotification(object state)
        {
            //本演示中，只有一种消息，即定时器发送过来的用于更新HTML时间标签内容的消息

            if (_label_DateTime == null || state == null) return;

            if ((state is string))
            {
                var key = state as string;
                if (key != "TimerEvent") return;

                //确定是定时器发送过来的消息
                var txt = DateTime.Now.ToString("yyy-MM-dd  HH:mm:ss");
                _label_DateTime.Text = txt;
            }
        }



        /// <summary>
        /// 定时器事件
        /// </summary>
        /// <param name="o"></param>
        private void MyTimerEvent(object o)
        {
            // 系统定时器事件来源于其它线程
            // 所以，原则上不直接操作窗体对象
            // 因此，通过向窗体发送一个消息，让窗体主线程得到消息事件而进行处理
            PostNotification("TimerEvent");

            // 不直接操作
            // var d = DateTime.Now.ToString("yyy年MM月dd日 HH时mm分ss秒");
            //_label_DateTime.Value = new SciterValue(d);
        }

        private FrmHtmlFormData _frmHtmlFormData;

        /// <summary>
        /// 除按钮类之外的其它HTML元素被点击
        /// </summary>
        /// <param name="target"></param>
        /// <returns></returns>
        protected override bool OnClick(SciterElement target)
        {
            // 获取被点击HTML元素的ID标记
            var id = target == null ? "" : target.GetId();

            // 根据ID进行处理
            switch (id)
            {
                case "div_button_1":
                    ShowMessageBox("【自定义(模拟)按钮一】被点击");
                    return true;

                case "div_button_2":
                    ShowMessageBox("【自定义(模拟)按钮二】被点击");
                    return true;

                //打开新窗口
                case "div_button_open1":
                    target.SetStyle("background-color", "#e8e8e8");        //修改背景色，让其看起来是被锁定状态
                    target.SetEnable(false);                               //锁定该按钮，使其不活动，防止被重复点击。（因新开的窗口不是模式窗，不会锁定父窗体）
                    _frmHtmlFormData = new FrmHtmlFormData(this, target);  //新建窗口
                    WinApplication.Show(_frmHtmlFormData);                 //显示窗体
                    return true;

                //打开对话框样式的演示窗体
                case "div_button_opendialog":
                    WinApplication.Show(new FrmDialog(this));
                    return true;
            }

            return base.OnClick(target);
        }

        /// <summary>
        /// 子窗体发送关闭事件
        /// </summary>
        /// <param name="form"></param>
        protected override void OnChildClose(Form form)
        {
            //如果被关闭的子窗体是按钮3打开的，就解除对该按钮的锁定
            if (form != null && form == _frmHtmlFormData)
            {
                _frmHtmlFormData.Button.SetEnable(true);                           //解除锁定，使之能活动
                _frmHtmlFormData.Button.SetStyle("background-color", null);        //恢复原来的背景色
                _frmHtmlFormData = null;  //因其已经关闭
            }

        }

        /// <summary>
        /// 本窗体关闭事件
        /// </summary>
        protected override void OnClose()
        {
            //释放定时器
            if (_dtTimer != null)
            {
                _dtTimer.Dispose();
                _dtTimer = null;
            }

        }



    }
}
