﻿using System;
using Sciter.Forms;
using Sciter;

namespace Demo3
{

    /************************************************
     *  本窗体演示的是登录验证
     *  ===========================================
     *  1，按钮点击事件与键盘按键事件的捕获与处理
     *  2，获取HTML指定对象的值以及对指定对象赋值
     * **********************************************/


    /// <summary>
    /// 登录窗
    /// </summary>
    public class FrmLogin : Form
    {

        /// <summary>
        /// 自定义的变量：是否登录成功
        /// </summary>
        public bool Login { get; private set; }



        /// <summary>
        /// 登录窗构造函数
        /// </summary>
        public FrmLogin(Form parent) : base(parent)
        {
            if (parent == null) {
                var messagge = "登录窗是子窗体，父窗体不能为空";
                ShowMessageBox(messagge, "错误", MessageBox.MsgIcon.Error);
                throw new Exception(messagge);
            }

            // 在窗体类的构造函数中，对窗体HTML、大小、图标等关键属性赋值

            Title = "Sciter.Forms 界面库 Demo";            // 窗口标题
            Width = 800;                                   // 窗口宽度
            Height = 500;                                  // 窗口高度
            CanDrag = true;                                // 拖动窗口空白处能否移动窗体
            StartupPage = Properties.Resources.FrmLogin;   // 窗口主HTML页数据;
            WindowStyle = WindowStyles.FixedSize;          // 窗口样式

            Icon = Properties.Resources.fox1.Handle;       // 窗口图标
            IconInTaskBar = true;                          // 让本子窗体的图标能在任务栏中显示

        }


        /// <summary>
        /// 网页加载完成
        /// </summary>
        /// <param name="el"></param>
        protected override void OnReady(SciterElement el)
        {
            if (el.Parent == null) el.SetFocus();
        }

        
        /// <summary>
        /// HTML窗体拟加载网页/网页元素事件
        /// </summary>
        /// <param name="path"></param>
        /// <returns></returns>
        protected override byte[] OnLoadData(string path)
        {

            // 说明：
            // 如果路径属于您的程序所定义的私有文件路径和文件名，就返回其二进制数据
            // 否则返回NULL（请不要调用基类的同名方法，基类也是返回NULL的）

            return null;
        }



        /// <summary>
        /// 鼠标点击按钮事件（消息）
        /// </summary>
        /// <param name="sender">发生事件的按钮对象</param>
        protected override bool OnButtonClick(SciterElement sender)
        {

            // 强调：关于消息响应的返回值
            // ================================================================
            // 返回 true：表示本后端已经接手了对该消息的处理（不管成功失败），
            //            这时，前端Html引擎将不会把该消息再向下一个元素传递
            // 返回 fase：表示本后端不接受对这个消息的处理，
            //            这时，前端Html引擎会把消息向下一个元素传递


            // 下边演示的是：验证用户输入的用户名、密码是否正确
            // 并根据验证结果作出错误提示或关闭窗口进入下一环节的不同选择
            // -----------------------------------------------------------------
            // 强调：** 对于html表单提交，应该用 OnFormSubit 事件，因为可以直接得到html form数据
            //       本demo 在 OnButtonClick 中实施登录验证，只是为了演示
            //=================================================================

            // 确定发送事件的对象是不是提交按钮，不是就返回
            if (sender == null || sender.GetId() != "verify_it") return false;
            //返回fase，表示该消息与已无关，“悉听尊便”


            //与已有关，接手处理

            //获取输入的用户名
            var se_uid = GetElementById("uid", sender.Parent);
            var uid = se_uid == null ? "" : se_uid.Value.Get("");

            //获取输入的密码
            var se_pwd = GetElementById("pwd", sender.Parent);
            var pwd = se_pwd == null ? "" : se_pwd.Value.Get("");

            //验证成功
            if (pwd == "666" && uid == "yunei")
            {
                Login = true;     //更改变量
                Close();          //关闭窗口
                return true;      //回应消息
            }

            //验证失败，提供错误提示
            var se_message = sender.Parent.SelectFirstById("label1");
            if (se_message != null) se_message.Value = new SciterValue("验证失败，请你重新输入");

            //应答true，表示该事件已经处理过了，不需要这个消息向其它环节传递
            return true;

        }


        /// <summary>
        /// 响应键盘键被按下的事件（消息）
        /// </summary>
        /// <param name="se">发出消息的对象</param>
        /// <param name="keycode">按键号</param>
        /// <returns></returns>
        protected override bool OnKeyDown(SciterElement se, ConsoleKey keycode)
        {
            // 如果按下的是ESC键，就退出程序
            if (keycode == ConsoleKey.Escape) { Close(); return true; }

            // 下面演示的是：
            // 在密码框中按下回车键时产生提交按钮被点击的效果
            // 思路：
            //   1，确定是否是在密码输入框中按下的是回车键
            //   2，“冒充”提交按钮发送“按钮被点击”消息
            // =========================================================


            //确定是否是回车键被按下（回车键编号13）
            if (keycode != ConsoleKey.Enter || se == null) return false;

            //根据id号确定当前元素是不是密码框
            var id = se.GetId();
            if (id != "pwd") return false;

            //找出提交按钮（id号是verify_it）这个元素对象
            var verify = GetElementById("verify_it");
            if (verify == null) return false;

            //以verify_it按键的名义发送“按钮被点击”的信号
            //其中“按钮元素被点击”的事件号是0
            return se.SendEvent(0, 0, verify);
        }


        /// <summary>
        /// 本窗体被关闭事件
        /// </summary>
        protected override void OnClose()
        {
            //可以在关闭前干一些扫尾工作
        }



    }
}
