﻿using System;
using Sciter;
using Sciter.Forms;
using System.Diagnostics;

namespace Demo4.Forms
{
    class FrmMain : Form
    {


        public FrmMain()
        {

            Width = 960;
            Height = 540;
            WindowStyle = WindowStyles.FixedSize;
            Icon = WinApplication.ExeIconFirst;
            StartupPagePath = "Views/FrmMain.html";
        }

        /// <summary>
        /// 主表的bbody部分
        /// </summary>
        private SciterElement _MainTable_tbody;

        /// <summary>
        /// 录入用户信息的表单
        /// </summary>
        private SciterElement _UserInfo_form;


        /// <summary>
        /// HTML加载完成
        /// </summary>
        /// <param name="el"></param>
        protected override void OnReady(SciterElement el)
        {
            _MainTable_tbody = el.SelectFirst("table#table_main>tbody");
            Debug.Assert(_MainTable_tbody != null, "没有找到主表的tbody元素");

            _UserInfo_form = el.SelectFirstById("info_input");
            Debug.Assert(_UserInfo_form != null);
        }


        /// <summary>
        /// 菜单项被点击事件
        /// </summary>
        /// <param name="source"></param>
        /// <param name="target"></param>
        /// <returns></returns>
        protected override bool OnMenuItemClick(SciterElement source, SciterElement target)
        {
            Debug.Assert(source != null);
            Debug.Assert(target != null);

            var menu_id = source.GetId();
            if (string.IsNullOrEmpty(menu_id) || target.Parent == null) return false;

            // 根据不同的菜单选项进行不同的操作
            switch (menu_id)
            {
                //如果删除项被点击
                case "menu_delete":
                    //确认父级元素是表格行
                    //因为右键事件是在单元格发生的，所以，它的父级元素才是表格的行
                    if (target.Parent.Tag.ToLower() == "tr")
                    {
                        //获取该行第1列的内容
                        var name = target.Parent.GetChild(0).Text;
                        //选择性提示
                        if (!ShowMessageBox2(string.Format("真的要删除姓名为 '{0}' 的员工记录么？", name), "删除提示")) break;
                        //删除该行
                        target.Parent.Delete();
                        return true;

                        //注：如果要操作数据库，应该为每行设置一个ID标签，C#获取该行ID后就可以进行数据库相关操作
                    }
                    return true;

                // 显示内容详情
                case "menu_view":
                    var name1 = target.Parent.GetChild(0).Text;
                    var home1 = target.Parent.GetChild(1).Text;
                    ShowMessageBox(string.Format("员工姓名：{0}\r\n家庭住址：{1}", name1, home1), MessageBox.MsgIcon.None);
                    return true;

                // 清空表格
                case "menu_clean":
                    _MainTable_tbody.Value = SciterValue.Null;
                    return true;

            }


            return base.OnMenuItemClick(source, target);
        }


        /// <summary>
        /// 按钮点击事件
        /// </summary>
        /// <param name="source"></param>
        /// <returns></returns>
        protected override bool OnButtonClick(SciterElement source)
        {
            if (source == null) return false;
            var buttonid = source.GetId();
            switch (buttonid)
            {
                case "but_add":
                    AddUserInfo();
                    break;

            }


            return false;

        }


        /// <summary>
        /// 与HTML中录入用户信息的表单对应的c#类
        /// </summary>
        class UsrInfo
        {
            public string UsrName = "";
            public string UsrHome = "";
        }

        /// <summary>
        /// 添加一条记录
        /// </summary>
        void AddUserInfo()
        {
            //将HTML表单内容转化为c#对象
            var info = _UserInfo_form.Value.MapToClass<UsrInfo>();

            info.UsrName = info.UsrName.Trim();
            info.UsrHome = info.UsrHome.Trim();

            //检查
            if (string.IsNullOrEmpty(info.UsrName) || string.IsNullOrEmpty(info.UsrHome))
            {
                ShowMessageBox("员工姓名或住值不能为空");
                return;
            }

            // 向表格添加一新行
            var tr = SciterElement.Create("tr");
            _MainTable_tbody.Append(tr);

            // 为该行设ID，可以与数据库ID对应，方便数据库操作
            var id = "u_" + (DateTime.Now.Ticks / 100000).ToString("x");
            tr.SetAttribute("id", id);                  //为该行记录设置id标签
            tr.SetAttribute("title", "员工ID：" + id);  //鼠标靠近该行时的提示

            // 向新行添加第一列
            var td1 = SciterElement.Create("td", info.UsrName);
            tr.Append(td1);  //该行的第一列
            //向新行添加第二列
            var td2 = SciterElement.Create("td", info.UsrHome);
            tr.Append(td2);

            // 清空录入框
            _UserInfo_form.Value = SciterValue.Null;

        }


    }
}
